#
# spec file for package ueberzugpp
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define short_name ueberzug
Name:           ueberzugpp
Version:        2.9.2
Release:        1.1
Summary:        Utility to render images in terminals
License:        GPL-3.0-or-later
URL:            https://github.com/jstkdng/%{name}
Source:         https://github.com/jstkdng/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  make
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  cmake(Microsoft.GSL)
BuildRequires:  cmake(spdlog)
BuildRequires:  pkgconfig(CLI11)
BuildRequires:  pkgconfig(botan-2)
BuildRequires:  pkgconfig(chafa)
BuildRequires:  pkgconfig(libsixel)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(opencv4)
BuildRequires:  pkgconfig(tbb)
BuildRequires:  pkgconfig(vips)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xcb-image)

%description
Überzug++ is a C++ command line utility which allows to draw images
on terminals by using child windows or using sixel on supported
terminals. (This is a drop-in replacement for the now defunct
ueberzug project.)

Advantages over w3mimgdisplay and ueberzug:

- support for wayland (sway only)
- no race conditions as a new window is created to display images
- "expose" events will be processed, so that images will be
  redrawn when switching workspaces
- tmux support on X11
- terminals without the WINDOWID environment variable are supported
- chars are used as position and size unit
- A lot of image formats are supported (through opencv and libvips)
- GIF and animated WEBP support on X11 and Sixel
- Resized images are cached for faster viewing

%prep
%autosetup

%build
%cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} -DCMAKE_SKIP_RPATH=YES -DCMAKE_BUILD_TYPE=release -DENABLE_WLROOTS=ON
%cmake_build

%install
%cmake_install
rm -v %{buildroot}%{_mandir}/man1/ueberzug.1
ln -s %{_mandir}/man1/ueberzugpp.1 %{buildroot}%{_mandir}/man1/ueberzug.1

%files
%{_bindir}/%{short_name}
%{_bindir}/%{short_name}pp
%license LICENSE
%doc README.md
%{_mandir}/man1/%{short_name}.1%{?ext_man}
%{_mandir}/man1/%{short_name}pp.1%{?ext_man}

%changelog
* Sun Jan 28 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 2.9.2:
  * support kitty 0.30
  * improve code correctness
* Sun Aug 20 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.9.1:
  * Fix compilation errors on spdlog 1.12, fmt 10.x and turbo-base64
  * Bump internal dependencies versions
* Tue Aug  8 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.9.0:
  * opengl support for X11 and wayland
  * add support for MacOS 11 Big Sur
  * add support for wayfire (plugin required)
  * fix memory leak when using wayland and tmux
  * performance improvements for wayland
  * use `XDG_CACHE_HOME` when available
* Tue Jul 18 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.9:
  * support for multiple images being displayed at the same time, images with the same identifier will be replaced
  * improved terminal recognition (deeply nested terminals are recognized correctly)
  * improved image positioning under wayland
  * improved multimonitor support under wayland
  * improved tmux support under wayland
  * code modernizing and cleanup
  * libressl support
  * small x11 performance improvements
* Fri Jun 23 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.8:
  * use xcb-res for obtaining pid of windows
  * use xcb-errors for useful error logging (disabled by default)
  * fix syncronization issues and performance improvements for x11 canvas
  * improve terminal selection
  * fixes for hyprland
  * improve throughput of unix socket
* Sat Jun 10 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.7:
  * add debian packaging
  * replace layer output flag `wlroots` in favor of `wayland`: it now works with any wayland wms, but only sway and hyprland have proper window positioning, hopefully add support for other wms in the future
  * support multiple monitors under sway and hyprland
  * peformance improvements for X11 canvas
  * update documentation
  * add more features to cmake install
  * improve libvips and opencv code
* Tue May 30 2023 Scott Bradnick <scott.bradnick@suse.com>
- Adding necessary "BuildRequires" to support `-DENABLE_WLROOTS=ON` after talking
  with developer
* Mon May 29 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.6:
  * add support for hyprland
  * fix bugs with command input/polling
  * fix regression when selecting a pty
  * remove uuid dependency
* Fri May 26 2023 Jan Engelhardt <jengelh@inai.de>
- Update summary to not assume special context (reference to
  ueberzug).
- Compact main description and weed out grammar errors.
* Fri May 26 2023 Scott Bradnick <scott.bradnick@suse.com>
- Updating description
- Update to version 2.8.5:
  * Wayland Support (only under sway and sway based wms)
  * remove zmq/cppzmq dependency (doesn't play well with unix sockets)
  * simplify code
* Mon May 22 2023 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 2.8.4:
  * code cleanup
  * improve performance for kitty and iterm2
  * simplify x11 and sixel canvas
  * add chafa canvas as a last resort canvas
  * minimum GCC version supported is 10.1
* Fri May 19 2023 Scott Bradnick <scott.bradnick@suse.com>
- Switching to traditional release vs. git release
* Tue May 16 2023 Scott Bradnick <scott.bradnick@suse.com>
- Switching to %%cmake macros
* Mon May 15 2023 scott.bradnick@suse.com
- Update to version 2.8.3+git20230515.df4e40f:
  * upgrade homebrew script
  * bump version and only add flags on debug builds
  * code cleanup
  * fix unused variable when opencv is disabled
  * use -Wall and fix recommendations
  * simpler signal handling and code cleanup
  * switch to using a singleton for accessing program configuration
  * code refactoring
* Sun May 14 2023 scott.bradnick@suse.com
- Update to version 2.8.2+git20230513.804060e:
  * fix iterm2 recognition
  * better logging, improved terminal detection and fix sixel bug
  * update README
  * handle terminal padding when running under tmux
  * code cleanup
  * remove some checks
  * util refactor
  * tmux handling
  * update fzf script
  * update lf script
  * take into account window padding on x11 canvas
  * update homebrew script
  * bump version
  * switch from uint64_t to size_t
  * fix build on macos
  * Bug fixes (#35)
  * follow audit guidelines
  * update homebrew
* Thu May 11 2023 scott.bradnick@suse.com
- Update to version 2.8.1+git20230511.9085896:
  * bump version
  * Code refactoring + bug fixes (#34)
  * add clang-tidy file
  * Update README.md
  * update README and remove image
  * improve homebrew script
  * update homebrew script
  * add sample gif
* Mon May  8 2023 scott.bradnick@suse.com
- Update to version 2.8.0+git20230507.b6cf910:
  * simplify homebrew script
  * follow homebrew audit guidelines
  * add homebrew script
  * try to download cppzmq if not present
  * update README
  * fix fzf script
  * bump version
  * better handle macos processes
  * cmake cleanup
  * remove action
  * use tbb on macos
  * open ttys
  * pidinfo fails for other user processes
  * test libproc
  * use stdout for now
  * add cppzmq
  * update
  * check sysctl
  * add macos workflow
  * small fix importing library
  * apple doesn't support execution policies
  * join threads just in case
  * switch from jthread to thread
  * extract required macro from library
  * switch from jthread to thread
  * fix cached images no longer being recognized by iterm2
  * update README.md
  * extract required macro from library
  * initial iterm2 support
  * fix lf script
  * improvements with cmd subcommand and add lf integration script
  * code cleanup and refactoring
  * update README
  * update README.md
  * parallellize kitty encoding
  * bump version
  * support cmake version 3.18
* Tue Apr 25 2023 scott.bradnick@suse.com
- Update to version 2.7.7+git20230425.63a3b72:
  * try to build third_part libraries if not installed
* Tue Apr 25 2023 scott.bradnick@suse.com
- Update to version 2.7.7+git20230424.527cc96:
  * hide turbo-base64 behind compiler flag
* Mon Apr 24 2023 scott.bradnick@suse.com
- Update to version 2.7.7+git20230424.a8d07a9:
  * test fetchcontent + new release
  * add ability to disable opencv or x11 at compile time
  * fix kitty not displaying image in certain cases
* Sat Apr 22 2023 scott.bradnick@suse.com
- Update to version 2.7.6+git20230421.0cccbe3:
  * bump version
  * synchronize main thread and drawing threads
  * add fzf integration script
  * add command flag
  * fix image scaling
* Sun Apr 16 2023 scott.bradnick@suse.com
- Update to version 2.7.5+git20230416.588af3b:
  * bump version
  * don't reset empty stringstream
  * restore cursor position with kitty
  * naming changes
  * sixel improvements
  * sixel improvements
  * verify if opencl is available
  * restore cache usage in opencv
  * initial support for additional image scalers
  * wezterm fixed its kitty support
* Thu Apr 13 2023 scott.bradnick@suse.com
- Update to version 2.7.4+git20230413.49df37b:
  * bump version
* Thu Apr 13 2023 scott.bradnick@suse.com
- Update to version 2.7.3+git20230412.b34360e:
  * clear canvas before using it again
  * some performance changes
  * update README.md
* Mon Apr  3 2023 scott.bradnick@suse.com
- Update to version 2.7.3+git20230403.d5fad31:
  * add no-opencv flag
  * limit libvips cache
  * respect no_cache flag with libvips
  * respect no_cache option with libvips
  * use only libvips
  * use opencv mainly again
  * add missing iniclude for older compilers
  * use resize instead of thumbnail_image
  * test libvips only
  * add no-cache flag
* Sat Mar 25 2023 scott.bradnick@suse.com
- Update to version 2.7.3+git20230324.4d09378:
  * add None install configuration
  * bump version
  * fix socket not being deleted
  * fix tmux regression
  * use smart pointers
  * using SIXEL_LARGE_LUM seems to improve performance
  * use ueberzugpp for files/directories
* Wed Mar 15 2023 scott.bradnick@suse.com
- Update to version 2.7.2+git20230315.fa5bef6:
  * bump version
  * add benchmark function
  * some code refactoring
  * Fix uninitialized read in X11Util::get_window_pid
  * Fix use of delete operator on result of malloc()
  * Add missing <thread> include to application.hpp
  * Fix make install
* Mon Mar 13 2023 scott.bradnick@suse.com
- Update to version 2.7.1+git20230312.b470797:
  * code cleaning
  * bump version and fix flags default
  * allow multiple instances of ueberzug to run at the same time
  * kitty validations, prepare for iterm2 canvas
* Fri Mar 10 2023 scott.bradnick@suse.com
- Update to version 2.7.0+git20230310.2c547ca:
  * update README.md
  * bump version
  * link to Crypto instead of SSL
  * handle parse errors and recognize more options
  * parse configuration file if exists
  * improve compatibility
  * code cleanup
  * use openssl instead of botan
  * test openssl for base64 encoding
  * improve kitty performance
  * better kitty recognition
  * initial kitty support
  * add kitty files
  * formatting issues
* Wed Mar  8 2023 scott.bradnick@suse.com
- Update to version 2.6.0+git20230308.97a5b80:
  * bug fixes
  * remove iostream
  * hard code sixel support for some terminals
  * change name of ESC
  * some changes
  * remove benchmarking code
  * only use opencl if required
  * use map instead of ifs
  * better tmux hook handling + functioning image cache
  * cache images properly
* Mon Mar  6 2023 scott.bradnick@suse.com
- Update to version 2.5.0+git20230306.39514c0:
  * update sample script
  * prepare for new outputs
  * fix pty selection regression
  * update README, plus performance enhancements
  * remove debug print
  * hide windows when tmux window changed
* Sun Mar  5 2023 scott.bradnick@suse.com
- Update to version 2.5.0+git20230305.c9478aa:
  * handle pane resizes
  * use unix sockets instead of tcp
  * correctly handle tmux hooks
  * register/unregister tmux hooks
  * better tcp handling v2
  * better tcp handling
  * send message to tcp on tmux hooks
  * add tmux hook subcommand
* Wed Mar  1 2023 scott.bradnick@suse.com
- Update to version 2.4.0+git20230227.fc36c72:
  * synchronize threads
  * rollback last commit
  * let each window handle it's own connection
  * better cli option handling
  * more optimizations for libvips
  * add license header
  * libvips optimizations
  * don't log twice
  * Don't crash on a failure to load an image
  * Handle status==off in tmux::get_statusbar_offset()
  * take in account vertical multine tmux statusbar
* Sat Feb 25 2023 scott.bradnick@suse.com
- Update to version 2.3.0+git20230225.39e38a8:
  * improve opencl
  * actually try to use opencl
  * add validations
  * bump patch
  * bump version
  * use references instead of shared_ptr
  * cleaning code
  * find control terminal correctly
  * some refactoring
  * bump version
  * update README.md
  * better backwards compatibility
  * docs: remove  symbol from Build section
* Fri Feb 24 2023 scott.bradnick@suse.com
- Update to version 2.2.0+git20230223.7c68553:
  * Update README.md
  * fix option not working
  * update README
  * handle more flags
  * add zmq dependency
  * don't save vips loader
* Thu Feb 23 2023 scott.bradnick@suse.com
- Update to version 2.1.0+git20230222.06779d3:
  * bump version
  * do less work on cached images
  * use a proper logger
* Wed Feb 22 2023 scott.bradnick@suse.com
- Update to version 2.0.0+git20230222.2be53a8:
  * new release
  * cache resized images
  * pass loader used to libvips image
  * use libvips for displaying gifs and animated webps
  * fix ueberzug window appearing in wrong positions
  * some refactoring
* Sun Feb 19 2023 scott.bradnick@suse.com
- Update to version 1.9.1+git20230218.7913178:
  * bump version
  * fix image not being redraw on expose events
  * bump version
  * create x11 windows the same size as the resized image
  * better image resizing
  * add versioning and some refactoring
  * fix type in README
  * new release
  * log program version
  * better sixel output
  * Update README.md
  * Update README.md
* Thu Feb 16 2023 scott.bradnick@suse.com
- Update to version 1.7.0+git20230216.f1b670c:
  * add some validations
  * resolving merge conflict
  * better sixel output
  * marked call operator of callable object "const"
  * Defaulted empty dtor, removed empty implementation.
  * defaulted empty dtor
  * defaulted empty dtor and removed implementation of it from source file
  * Removing unnecessary assignment of nullptr to unique_ptr members in in-class initializer.
  * Removed extraneous semicolons, defaulted dtor implementation. Added .vs temporaries directory to git ignore.
  * better sixel support
  * don't use printf
* Tue Feb 14 2023 scott.bradnick@suse.com
- Update to version 1.6.0+git20230214.f016a6f:
  * complete gif support for sixel
  * test sixel gif support
* Mon Feb 13 2023 scott.bradnick@suse.com
- Update to version 1.5.0+git20230213.ab00bf2:
  * better image format handling
  * update README.md
  * add gif support to x11 canvas
  * prepare gif support
  * don't overlap with borders
  * bug fixing
  * update README.md
  * remove comments
  * cleaning
